simple-cors.core


compile-cors-any-origin-configclj/s

(compile-cors-any-origin-config config)

Compile cors for any origin

Compile cors for any origin
sourceraw docstring

compile-cors-configclj/s

(compile-cors-config config)
source

compile-cors-fn-origin-configclj/s

(compile-cors-fn-origin-config config)

Slow but flexible cors

Slow but flexible cors
sourceraw docstring

compile-cors-static-configclj/s

(compile-cors-static-config config)

Compile CORS config to map[string,CORSOriginHandler]

Compile CORS config to map[string,CORSOriginHandler]
sourceraw docstring

CORSOriginAnyOriginHandlercljs

source

CORSOriginFnHandlercljs

source

CORSOriginHandlerclj/sprotocol

add-headers-to-responseclj/s

(add-headers-to-response this response request-origin)

Add CORS headers to response for the origin

Add CORS headers to response for the origin

originclj/s

(origin this)

Origin that this handler can handle

Origin that this handler can handle

preflight-responseclj/s

(preflight-response this request-origin)

Success preflight response for the origin

Success preflight response for the origin
source

CORSOriginHandlerLookupclj/sprotocol

get-handlerclj/s

(get-handler this request-origin)
source

CORSOriginStaticHandlercljs

source

default-preflight-forbidden-responseclj/s

source

default-preflight-ok-responseclj/s

source

get-originclj/s

(get-origin req)
source

handle-preflightclj/s

(handle-preflight cors-handler request-origin forbidden-response ok-response)
source

make-cors-preflight-handlerclj/s

(make-cors-preflight-handler cors forbidden-response ok-response)

Create a ring handler fn that only handle preflight request

Create a ring handler fn that only handle preflight request
sourceraw docstring

preflight-request?clj/s

(preflight-request? req)

Check if the ring request is a valid preflight request

Check if the ring request is a valid preflight request
sourceraw docstring

preflight-response-headersclj/s

(preflight-response-headers config origin)

Generate preflight response headers from config

Generate preflight response headers from config
sourceraw docstring

response-headersclj/s

(response-headers config origin)

Generate CORS headers for a valid request

Generate CORS headers for a valid request
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries