simple-cors.reitit.interceptor


cors-interceptorclj/s

(cors-interceptor {:keys [cors-config]})

This interceptor is intended to be used in reitit. Since reitit using a separate handler to handle {:request-method :options}, all preflight handling logic will not exists in this interceptor

This interceptor is intended to be used in reitit.
Since reitit using a separate handler to handle {:request-method :options},
all preflight handling logic will not exists in this interceptor
sourceraw docstring

make-default-options-endpointclj/s

(make-default-options-endpoint
  {:keys [cors-config preflight-forbidden-response preflight-ok-response]
   :or {preflight-forbidden-response cors/default-preflight-forbidden-response
        preflight-ok-response cors/default-preflight-ok-response}})
source

cljdoc builds & hosts documentation for Clojure/Script libraries