(compile-cors-any-origin-config config)Compile cors for any origin
Compile cors for any origin
(compile-cors-fn-origin-config config)Slow but flexible cors
Slow but flexible cors
(compile-cors-static-config config)Compile CORS config to map[string,CORSOriginHandler]
Compile CORS config to map[string,CORSOriginHandler]
(add-headers-to-response this response request-origin)Add CORS headers to response for the origin
Add CORS headers to response for the origin
(origin this)Origin that this handler can handle
Origin that this handler can handle
(preflight-response this request-origin)Success preflight response for the origin
Success preflight response for the origin
(handle-preflight cors-handler request-origin forbidden-response ok-response)(make-cors-preflight-handler cors forbidden-response ok-response)Create a ring handler fn that only handle preflight request
Create a ring handler fn that only handle preflight request
(preflight-request? req)Check if the ring request is a valid preflight request
Check if the ring request is a valid preflight request
(preflight-response-headers config origin)Generate preflight response headers from config
Generate preflight response headers from config
(response-headers config origin)Generate CORS headers for a valid request
Generate CORS headers for a valid request
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |