(cors-interceptor {:keys [cors-config]})This interceptor is intended to be used in reitit. Since reitit using a separate handler to handle {:request-method :options}, all preflight handling logic will not exists in this interceptor
This interceptor is intended to be used in reitit.
Since reitit using a separate handler to handle {:request-method :options},
all preflight handling logic will not exists in this interceptor(make-default-options-endpoint
{:keys [cors-config preflight-forbidden-response preflight-ok-response]
:or {preflight-forbidden-response cors/default-preflight-forbidden-response
preflight-ok-response cors/default-preflight-ok-response}})cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |